# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.checkout_session_line_item_data_response import CheckoutSessionLineItemDataResponse

class TestCheckoutSessionLineItemDataResponse(unittest.TestCase):
    """CheckoutSessionLineItemDataResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CheckoutSessionLineItemDataResponse:
        """Test CheckoutSessionLineItemDataResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CheckoutSessionLineItemDataResponse`
        """
        model = CheckoutSessionLineItemDataResponse()
        if include_optional:
            return CheckoutSessionLineItemDataResponse(
                object = 'line_item',
                id = '',
                amount_subtotal = 56,
                amount_tax = 56,
                amount_total = 56,
                currency = 'jpy',
                description = '',
                price = payjpv2.models.price_details_response.PriceDetailsResponse(
                    id = '', 
                    object = 'price', 
                    livemode = True, 
                    active = True, 
                    metadata = {
                        'key' : null
                        }, 
                    nickname = '', 
                    type = 'one_time', 
                    lookup_key = '', 
                    currency = 'jpy', 
                    product_id = '', 
                    unit_amount = 56, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                quantity = 56
            )
        else:
            return CheckoutSessionLineItemDataResponse(
                id = '',
                amount_subtotal = 56,
                amount_tax = 56,
                amount_total = 56,
                currency = 'jpy',
                description = '',
                price = payjpv2.models.price_details_response.PriceDetailsResponse(
                    id = '', 
                    object = 'price', 
                    livemode = True, 
                    active = True, 
                    metadata = {
                        'key' : null
                        }, 
                    nickname = '', 
                    type = 'one_time', 
                    lookup_key = '', 
                    currency = 'jpy', 
                    product_id = '', 
                    unit_amount = 56, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                quantity = 56,
        )
        """

    def testCheckoutSessionLineItemDataResponse(self):
        """Test CheckoutSessionLineItemDataResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
