# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.api.payment_methods_api import PaymentMethodsApi


class TestPaymentMethodsApi(unittest.TestCase):
    """PaymentMethodsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentMethodsApi()

    def tearDown(self) -> None:
        pass

    def test_attach_payment_method(self) -> None:
        """Test case for attach_payment_method

        Attach Payment Method
        """
        pass

    def test_create_payment_method(self) -> None:
        """Test case for create_payment_method

        Create Payment Method
        """
        pass

    def test_detach_payment_method(self) -> None:
        """Test case for detach_payment_method

        Detach Payment Method
        """
        pass

    def test_get_all_payment_methods(self) -> None:
        """Test case for get_all_payment_methods

        Get All Payment Methods
        """
        pass

    def test_get_payment_method(self) -> None:
        """Test case for get_payment_method

        Get Payment Method
        """
        pass

    def test_get_payment_method_by_card(self) -> None:
        """Test case for get_payment_method_by_card

        Get Payment Method By Card
        """
        pass

    def test_update_payment_method(self) -> None:
        """Test case for update_payment_method

        Update Payment Method
        """
        pass


if __name__ == '__main__':
    unittest.main()
