# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.product_details_response import ProductDetailsResponse

class TestProductDetailsResponse(unittest.TestCase):
    """ProductDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProductDetailsResponse:
        """Test ProductDetailsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProductDetailsResponse`
        """
        model = ProductDetailsResponse()
        if include_optional:
            return ProductDetailsResponse(
                id = '',
                object = 'product',
                name = '',
                active = True,
                default_price_id = '',
                description = '',
                unit_label = '',
                url = ''
            )
        else:
            return ProductDetailsResponse(
                id = '',
                name = '',
                active = True,
                default_price_id = '',
                description = '',
                unit_label = '',
                url = '',
        )
        """

    def testProductDetailsResponse(self):
        """Test ProductDetailsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
