# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.term_list_response import TermListResponse

class TestTermListResponse(unittest.TestCase):
    """TermListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TermListResponse:
        """Test TermListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TermListResponse`
        """
        model = TermListResponse()
        if include_optional:
            return TermListResponse(
                object = 'list',
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.term_response.TermResponse(
                        id = '', 
                        object = 'term', 
                        livemode = True, 
                        start_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        end_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        closed = True, )
                    ]
            )
        else:
            return TermListResponse(
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.term_response.TermResponse(
                        id = '', 
                        object = 'term', 
                        livemode = True, 
                        start_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        end_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        closed = True, )
                    ],
        )
        """

    def testTermListResponse(self):
        """Test TermListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
