# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.api.payment_transactions_api import PaymentTransactionsApi


class TestPaymentTransactionsApi(unittest.TestCase):
    """PaymentTransactionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentTransactionsApi()

    def tearDown(self) -> None:
        pass

    def test_get_all_payment_transactions(self) -> None:
        """Test case for get_all_payment_transactions

        Get All Payment Transactions
        """
        pass

    def test_get_payment_transaction(self) -> None:
        """Test case for get_payment_transaction

        Get Payment Transaction
        """
        pass


if __name__ == '__main__':
    unittest.main()
