# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.product_list_response import ProductListResponse

class TestProductListResponse(unittest.TestCase):
    """ProductListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProductListResponse:
        """Test ProductListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProductListResponse`
        """
        model = ProductListResponse()
        if include_optional:
            return ProductListResponse(
                object = 'list',
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.product_details_response.ProductDetailsResponse(
                        id = '', 
                        object = 'product', 
                        name = '', 
                        active = True, 
                        default_price_id = '', 
                        description = '', 
                        unit_label = '', 
                        url = '', )
                    ]
            )
        else:
            return ProductListResponse(
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.product_details_response.ProductDetailsResponse(
                        id = '', 
                        object = 'product', 
                        name = '', 
                        active = True, 
                        default_price_id = '', 
                        description = '', 
                        unit_label = '', 
                        url = '', )
                    ],
        )
        """

    def testProductListResponse(self):
        """Test ProductListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
