# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.payment_method_response import PaymentMethodResponse

class TestPaymentMethodResponse(unittest.TestCase):
    """PaymentMethodResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaymentMethodResponse:
        """Test PaymentMethodResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaymentMethodResponse`
        """
        model = PaymentMethodResponse()
        if include_optional:
            return PaymentMethodResponse(
                object = 'payment_method',
                id = '',
                type = 'card',
                customer_id = '',
                detached_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                livemode = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                metadata = {
                    'key' : null
                    },
                billing_details = payjpv2.models.payment_method_billing_details_response.PaymentMethodBillingDetailsResponse(
                    name = '', 
                    phone = '', 
                    email = '', 
                    address = payjpv2.models.payment_method_billing_address_response.PaymentMethodBillingAddressResponse(
                        country = '', 
                        zip = '', 
                        state = '', 
                        city = '', 
                        line1 = '', 
                        line2 = '', ), ),
                card = payjpv2.models.payment_method_card_details_response.PaymentMethodCardDetailsResponse(
                    last4 = '', 
                    brand = '', 
                    exp_month = 56, 
                    exp_year = 56, 
                    fingerprint = '', 
                    country = '', )
            )
        else:
            return PaymentMethodResponse(
                id = '',
                type = 'card',
                customer_id = '',
                detached_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                livemode = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                metadata = {
                    'key' : null
                    },
                billing_details = payjpv2.models.payment_method_billing_details_response.PaymentMethodBillingDetailsResponse(
                    name = '', 
                    phone = '', 
                    email = '', 
                    address = payjpv2.models.payment_method_billing_address_response.PaymentMethodBillingAddressResponse(
                        country = '', 
                        zip = '', 
                        state = '', 
                        city = '', 
                        line1 = '', 
                        line2 = '', ), ),
                card = payjpv2.models.payment_method_card_details_response.PaymentMethodCardDetailsResponse(
                    last4 = '', 
                    brand = '', 
                    exp_month = 56, 
                    exp_year = 56, 
                    fingerprint = '', 
                    country = '', ),
        )
        """

    def testPaymentMethodResponse(self):
        """Test PaymentMethodResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
