# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.checkout_session_details_response import CheckoutSessionDetailsResponse

class TestCheckoutSessionDetailsResponse(unittest.TestCase):
    """CheckoutSessionDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CheckoutSessionDetailsResponse:
        """Test CheckoutSessionDetailsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CheckoutSessionDetailsResponse`
        """
        model = CheckoutSessionDetailsResponse()
        if include_optional:
            return CheckoutSessionDetailsResponse(
                id = '',
                object = 'checkout.session',
                livemode = True,
                amount_subtotal = 56,
                amount_total = 56,
                cancel_url = '',
                customer_id = '',
                customer_email = '',
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                currency = 'jpy',
                locale = 'auto',
                payment_flow_id = '',
                payment_method_types = [
                    'card'
                    ],
                payment_method_options = { },
                setup_flow_id = '',
                submit_type = 'auto',
                mode = 'payment',
                ui_mode = 'hosted',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                metadata = {
                    'key' : null
                    },
                status = 'open',
                success_url = '',
                url = ''
            )
        else:
            return CheckoutSessionDetailsResponse(
                id = '',
                livemode = True,
                amount_subtotal = 56,
                amount_total = 56,
                cancel_url = '',
                customer_id = '',
                customer_email = '',
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                currency = 'jpy',
                locale = 'auto',
                payment_method_types = [
                    'card'
                    ],
                payment_method_options = { },
                submit_type = 'auto',
                mode = 'payment',
                ui_mode = 'hosted',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                metadata = {
                    'key' : null
                    },
                status = 'open',
                success_url = '',
                url = '',
        )
        """

    def testCheckoutSessionDetailsResponse(self):
        """Test CheckoutSessionDetailsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
